@@ -350,6 +350,16 @@ static void moserial_serial_connection_applySettings (moserialSerialConnection*
 			baudRate = B921600;
 			break;
 		}
+		case 1000000:
+		{
+			baudRate = B1000000;
+			break;
+		}
+		case 2000000:
+		{
+			baudRate = B2000000;
+			break;
+		}
 	}
 	cfsetospeed (&self->priv->newtio, baudRate);
 	cfsetispeed (&self->priv->newtio, baudRate);
